==> haskell-invariant-0.6.3-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 invariant
version:              0.6.3
visibility:           public
id:                   invariant-0.6.3-LmjwlQ1XTwcBSxLsWgi69U
key:                  invariant-0.6.3-LmjwlQ1XTwcBSxLsWgi69U
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  b8a82dd91f884c12fe33db660a7fbe3c
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.2.8/site-local/invariant-0.6.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/invariant-0.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.3-LmjwlQ1XTwcBSxLsWgi69U
depends:
    StateVar-1.2.2-4TJ8CI5wrC5B2qk02v8ZQ3 array-0.5.4.0 base-4.16.4.0
    bifunctors-5.6-ADEUrWrknc28U7HKfVMzZQ
    comonad-5.0.8-ECGCXO0IDm6CmzMMLQMWdW containers-0.6.5.1
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq ghc-prim-0.8.0
    profunctors-5.6.2-IwG4rHL6atH4Ka7pLrv2VH stm-2.5.0.2
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-6SQIi6GiFzoJl2Kyo4GEMQ

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-invariant-0.6.3-12-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 invariant
version:              0.6.3
visibility:           public
id:                   invariant-0.6.3-3MRvgcDSTOa1evAkJbyKEO
key:                  invariant-0.6.3-3MRvgcDSTOa1evAkJbyKEO
license:              BSD-2-Clause
maintainer:
    Nicolas Frisby <nicolas.frisby@gmail.com>,
    Ryan Scott <ryan.gl.scott@gmail.com>

author:               Nicolas Frisby <nicolas.frisby@gmail.com>
homepage:             https://github.com/nfrisby/invariant-functors
synopsis:             Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).

    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":

    <http://comonad.com/reader/2008/rotten-bananas/>

category:             Control, Data
abi:                  6fa50636862357067a82f88b32bf8acc
exposed:              True
exposed-modules:      Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules:       Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs:          /usr/lib/ghc-9.2.8/site-local/invariant-0.6.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/invariant-0.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-invariant
hs-libraries:         HSinvariant-0.6.3-3MRvgcDSTOa1evAkJbyKEO
depends:
    StateVar-1.2.2-4TJ8CI5wrC5B2qk02v8ZQ3 array-0.5.4.0 base-4.16.4.0
    bifunctors-5.6-Bb9FnxojxnmAAd961eYGAf
    comonad-5.0.8-ApzGC3RbXnnLePVoN4sF11 containers-0.6.5.1
    contravariant-1.5.5-6oWUjmJNxDBFhugVD5s9dq ghc-prim-0.8.0
    profunctors-5.6.2-FWe4PQU8eE3GeDqm3R4ckm stm-2.5.0.2
    tagged-0.8.8-404YCiJ2agdDxJGZ4AybXg template-haskell-2.18.0.0
    th-abstraction-0.4.5.0-FQrzhXbdvQX3Z0wTw3euNu transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS
    unordered-containers-0.2.20-4hqmnCstShmJXjUlp61Lcu

haddock-interfaces:   /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html:         /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
